@@ -23,10 +23,9 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.core
-import constructs
+from ._jsii import *
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-workspaces", "1.33.1", __name__, "aws-workspaces@1.33.1.jsii.tgz")
+import aws_cdk.core
 
 
 @jsii.implements(aws_cdk.core.IInspectable)
@@ -38,7 +37,7 @@ class CfnWorkspace(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
     cloudformationResource:
     :cloudformationResource:: AWS::WorkSpaces::Workspace
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, bundle_id: str, directory_id: str, user_name: str, root_volume_encryption_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None, user_volume_encryption_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, volume_encryption_key: typing.Optional[str]=None, workspace_properties: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["WorkspacePropertiesProperty"]]]=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, bundle_id: str, directory_id: str, user_name: str, root_volume_encryption_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None, user_volume_encryption_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, volume_encryption_key: typing.Optional[str]=None, workspace_properties: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkspacePropertiesProperty"]]=None) -> None:
         """Create a new ``AWS::WorkSpaces::Workspace``.
 
         :param scope: - scope in which this resource is defined.
@@ -56,6 +55,25 @@ class CfnWorkspace(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
         jsii.create(CfnWorkspace, self, [scope, id, props])
 
+    @jsii.member(jsii_name="fromCloudFormation")
+    @builtins.classmethod
+    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnWorkspace":
+        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
+
+        Used in the @aws-cdk/cloudformation-include module.
+
+        :param scope: -
+        :param id: -
+        :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
+
+        stability
+        :stability: experimental
+        """
+        options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
         """Examines the CloudFormation resource and discloses attributes.
@@ -68,7 +86,7 @@ class CfnWorkspace(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
+    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -82,7 +100,7 @@ class CfnWorkspace(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
     @builtins.property
     @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
+    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
         return jsii.get(self, "cfnProperties")
 
     @builtins.property
@@ -106,7 +124,7 @@ class CfnWorkspace(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "bundleId")
 
     @bundle_id.setter
-    def bundle_id(self, value: str):
+    def bundle_id(self, value: str) -> None:
         jsii.set(self, "bundleId", value)
 
     @builtins.property
@@ -120,7 +138,7 @@ class CfnWorkspace(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "directoryId")
 
     @directory_id.setter
-    def directory_id(self, value: str):
+    def directory_id(self, value: str) -> None:
         jsii.set(self, "directoryId", value)
 
     @builtins.property
@@ -134,12 +152,12 @@ class CfnWorkspace(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "userName")
 
     @user_name.setter
-    def user_name(self, value: str):
+    def user_name(self, value: str) -> None:
         jsii.set(self, "userName", value)
 
     @builtins.property
     @jsii.member(jsii_name="rootVolumeEncryptionEnabled")
-    def root_volume_encryption_enabled(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def root_volume_encryption_enabled(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::WorkSpaces::Workspace.RootVolumeEncryptionEnabled``.
 
         see
@@ -148,12 +166,12 @@ class CfnWorkspace(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "rootVolumeEncryptionEnabled")
 
     @root_volume_encryption_enabled.setter
-    def root_volume_encryption_enabled(self, value: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]):
+    def root_volume_encryption_enabled(self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]) -> None:
         jsii.set(self, "rootVolumeEncryptionEnabled", value)
 
     @builtins.property
     @jsii.member(jsii_name="userVolumeEncryptionEnabled")
-    def user_volume_encryption_enabled(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def user_volume_encryption_enabled(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::WorkSpaces::Workspace.UserVolumeEncryptionEnabled``.
 
         see
@@ -162,7 +180,7 @@ class CfnWorkspace(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "userVolumeEncryptionEnabled")
 
     @user_volume_encryption_enabled.setter
-    def user_volume_encryption_enabled(self, value: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]):
+    def user_volume_encryption_enabled(self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]) -> None:
         jsii.set(self, "userVolumeEncryptionEnabled", value)
 
     @builtins.property
@@ -176,12 +194,12 @@ class CfnWorkspace(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "volumeEncryptionKey")
 
     @volume_encryption_key.setter
-    def volume_encryption_key(self, value: typing.Optional[str]):
+    def volume_encryption_key(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "volumeEncryptionKey", value)
 
     @builtins.property
     @jsii.member(jsii_name="workspaceProperties")
-    def workspace_properties(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["WorkspacePropertiesProperty"]]]:
+    def workspace_properties(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkspacePropertiesProperty"]]:
         """``AWS::WorkSpaces::Workspace.WorkspaceProperties``.
 
         see
@@ -190,12 +208,12 @@ class CfnWorkspace(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
         return jsii.get(self, "workspaceProperties")
 
     @workspace_properties.setter
-    def workspace_properties(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["WorkspacePropertiesProperty"]]]):
+    def workspace_properties(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "WorkspacePropertiesProperty"]]) -> None:
         jsii.set(self, "workspaceProperties", value)
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-workspaces.CfnWorkspace.WorkspacePropertiesProperty", jsii_struct_bases=[], name_mapping={'compute_type_name': 'computeTypeName', 'root_volume_size_gib': 'rootVolumeSizeGib', 'running_mode': 'runningMode', 'running_mode_auto_stop_timeout_in_minutes': 'runningModeAutoStopTimeoutInMinutes', 'user_volume_size_gib': 'userVolumeSizeGib'})
     class WorkspacePropertiesProperty():
-        def __init__(self, *, compute_type_name: typing.Optional[str]=None, root_volume_size_gib: typing.Optional[jsii.Number]=None, running_mode: typing.Optional[str]=None, running_mode_auto_stop_timeout_in_minutes: typing.Optional[jsii.Number]=None, user_volume_size_gib: typing.Optional[jsii.Number]=None):
+        def __init__(self, *, compute_type_name: typing.Optional[str]=None, root_volume_size_gib: typing.Optional[jsii.Number]=None, running_mode: typing.Optional[str]=None, running_mode_auto_stop_timeout_in_minutes: typing.Optional[jsii.Number]=None, user_volume_size_gib: typing.Optional[jsii.Number]=None) -> None:
             """
             :param compute_type_name: ``CfnWorkspace.WorkspacePropertiesProperty.ComputeTypeName``.
             :param root_volume_size_gib: ``CfnWorkspace.WorkspacePropertiesProperty.RootVolumeSizeGib``.
@@ -272,7 +290,7 @@ class CfnWorkspace(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type=
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-workspaces.CfnWorkspaceProps", jsii_struct_bases=[], name_mapping={'bundle_id': 'bundleId', 'directory_id': 'directoryId', 'user_name': 'userName', 'root_volume_encryption_enabled': 'rootVolumeEncryptionEnabled', 'tags': 'tags', 'user_volume_encryption_enabled': 'userVolumeEncryptionEnabled', 'volume_encryption_key': 'volumeEncryptionKey', 'workspace_properties': 'workspaceProperties'})
 class CfnWorkspaceProps():
-    def __init__(self, *, bundle_id: str, directory_id: str, user_name: str, root_volume_encryption_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None, user_volume_encryption_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None, volume_encryption_key: typing.Optional[str]=None, workspace_properties: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkspace.WorkspacePropertiesProperty"]]]=None):
+    def __init__(self, *, bundle_id: str, directory_id: str, user_name: str, root_volume_encryption_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, tags: typing.Optional[typing.List[aws_cdk.core.CfnTag]]=None, user_volume_encryption_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, volume_encryption_key: typing.Optional[str]=None, workspace_properties: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkspace.WorkspacePropertiesProperty"]]=None) -> None:
         """Properties for defining a ``AWS::WorkSpaces::Workspace``.
 
         :param bundle_id: ``AWS::WorkSpaces::Workspace.BundleId``.
@@ -326,7 +344,7 @@ class CfnWorkspaceProps():
         return self._values.get('user_name')
 
     @builtins.property
-    def root_volume_encryption_enabled(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def root_volume_encryption_enabled(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::WorkSpaces::Workspace.RootVolumeEncryptionEnabled``.
 
         see
@@ -344,7 +362,7 @@ class CfnWorkspaceProps():
         return self._values.get('tags')
 
     @builtins.property
-    def user_volume_encryption_enabled(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+    def user_volume_encryption_enabled(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::WorkSpaces::Workspace.UserVolumeEncryptionEnabled``.
 
         see
@@ -362,7 +380,7 @@ class CfnWorkspaceProps():
         return self._values.get('volume_encryption_key')
 
     @builtins.property
-    def workspace_properties(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnWorkspace.WorkspacePropertiesProperty"]]]:
+    def workspace_properties(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnWorkspace.WorkspacePropertiesProperty"]]:
         """``AWS::WorkSpaces::Workspace.WorkspaceProperties``.
 
         see
@@ -380,6 +398,9 @@ class CfnWorkspaceProps():
         return 'CfnWorkspaceProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
-__all__ = ["CfnWorkspace", "CfnWorkspaceProps", "__jsii_assembly__"]
+__all__ = [
+    "CfnWorkspace",
+    "CfnWorkspaceProps",
+]
 
 publication.publish()
